==> serendipity-0.9.1_2.tbz: www/serendipity/plugins/serendipity_event_spamblock/lang_es.inc.php <==
<?php # $Id: lang_es.inc.php,v 1.0 2005/08/20 11:37:42 garvinhicking Exp $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation (c) by  Rodrigo Lazo <rlazo.paz@gmail.com>
/* vim: set sts=4 ts=4 expandtab : */

@define('PLUGIN_EVENT_SPAMBLOCK_TITLE', 'Proteccin anti-Spam');
@define('PLUGIN_EVENT_SPAMBLOCK_DESC', 'Una variedad de mtodos para prevenir el spam en los comentarios');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY', 'Proteccin anti-Spam: Mensaje invlido.');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_IP', 'Proteccin anti-Spam: No puedes colocar un nuevo comentario tan pronto luego de haber ya hecho uno.');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_KILLSWITCH', 'Este blog est en "Modo de Emergencia de Bloqueo de comentarios", por favor regresa ms tarde');
@define('PLUGIN_EVENT_SPAMBLOCK_BODYCLONE', 'No permitir comentarios duplicados');
@define('PLUGIN_EVENT_SPAMBLOCK_BODYCLONE_DESC', 'Evita que los usuarios envien un comentario que contiene el mismo cuerpo que un comentario distinto ya enviado');
@define('PLUGIN_EVENT_SPAMBLOCK_KILLSWITCH', 'Desactivacin de emergencia de comentarios');
@define('PLUGIN_EVENT_SPAMBLOCK_KILLSWITCH_DESC', 'Inhabilita temporalmente los comentarios de todas las entradas. til si tu blog est siendo atacado por spam.');
@define('PLUGIN_EVENT_SPAMBLOCK_IPFLOOD', 'Intervaluo de bloqueo IP');
@define('PLUGIN_EVENT_SPAMBLOCK_IPFLOOD_DESC', 'Permite enviar comentarios a un IP cada n minutos. til para prevenir sobrecarga de comentarios.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS', 'Activar Captchas');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_DESC', 'Forzar a los usuarios a introducir una cadena al azar mostrada en una imagen especialmente diseada. Esta opcin imposibilitar envos automticos a tu blog. Por favor ten en cuenta que personas con problemas visuales podran encontrar dificil leer los captchas.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC', 'Para prevenir un ataque spam en los comentarios por parte de bots, por favor ingresa la cadena que ves en la imagen mostrada ms abajo en la apropiada caja de texto. Tu comentario ser aceptado slo si ambas cadenas son iguales. Por favor, asegrate que tu navegador soporta y acepta cookies, o tu comentario no podr ser verificado correctamente.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC2', 'Ingresa la cadena que ves ms abajo en la caja de texto!');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC3', 'Ingresa la cadena de proteccin contra spam de la imgen mostrada abajo: ');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_CAPTCHAS', 'No has ingresado correctamente la cadena de proteccin contra spam mostrada en la imagen. Por favor, mrala e ingresa su valor en la caja de texto.');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_NOTTF', 'Captchas deshabilitados en tu servidor. Necesitas GDLib y las libreras freetype compiladas con PHP, adems que de los archivos .TTF residan en tu directorio.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_TTL', 'Forzar captchas luego de cuantos das');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_TTL_DESC', 'Los captchas pueden ser reforzados dependiendo de la edad de tu artculo. Ingresa la cantidad de das luego de los cuales ser necesario ingresar el captcha. Si lo defines en 0, siempre sern utilizados.');
@define('PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATION', 'Forzar la moderacin en los comentarios luego de cuntos das');
@define('PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATION_DESC', 'Puedes configurar todos los comentarios a las entradas como automticamente moderados. Ingresa la edad de la entrada en das, luego de la cual ser auto-moderada. 0 significa no auto-moderacin.');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_MODERATE', 'Cuntos enlaces antes de que se modere un comentario');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_MODERATE_DESC', 'Cuando un comentario alcanza una cierta cantidad de enlaces, se puede configurar para que sea moderado. 0 significa que no se realizar esta comprobacin de enlaces.');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_REJECT', 'Cuntos enlaces antes de que se rechace un comentario');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_REJECT_DESC', 'Cuando un comentario alcance un cierto nmero de enlaces, ese comentario puede ser rechazado. 0 significa que no se realizar esta comprobacin de enlaces.');
@define('PLUGIN_EVENT_SPAMBLOCK_NOTICE_MODERATION', 'Debido a ciertas condiciones, tu comentario ha sido marcado de manera que requiere moderacin por parte del dueo de este blog.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHA_COLOR', 'Color de fondo del captcha');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHA_COLOR_DESC', 'Ingresa valores RGB: 0,255,255');

@define('PLUGIN_EVENT_SPAMBLOCK_LOGFILE', 'Ubicacin de la bitcora(logfile)');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGFILE_DESC', 'Informacin sobre comentarios rechazados/moderados puede ser puede ser escrita en una bitcora. Si lo dejas en blanco no se har reporte alguno.');

@define('PLUGIN_EVENT_SPAMBLOCK_REASON_KILLSWITCH', 'Bloqueo de comentarios de emergencia');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_BODYCLONE', 'Comentario duplicado');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_IPFLOOD', 'Bloqueo IP');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_CAPTCHAS', 'Captcha invlido (Ingresado: %s, Esperado: %s)');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_FORCEMODERATION', 'Moderacin automtica luego de X das');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_LINKS_REJECT', 'Demasiados hiper-enlaces');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_LINKS_MODERATE', 'Demasiados hiper-enlaces');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL', 'Ocultar direcciones e-mail de los usuarios que comentan');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL_DESC', 'No mostrar direccin e-mail alguna de los usuarios que comenten');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL_NOTICE', 'Direcciones e-mail no sern mostradas y slo sern utilizadas para notificaciones a travs de esa va');

@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE', 'Elige el mtodo de reporte');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_DESC', 'Reportes sobre comentarios rechazados pueden ser hechos a travs de la base de datos o en un archivo de texto plano');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_FILE', 'Archivo (la opcin "logfile" debajo)');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_DB', 'Base de datos');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_NONE', 'Sin reporte');

@define('PLUGIN_EVENT_SPAMBLOCK_API_COMMENTS', 'Como manejar los comentarios hechos via APIs');
@define('PLUGIN_EVENT_SPAMBLOCK_API_COMMENTS_DESC', 'Esta opcin afecta la moderacin sobre los comentarios hechos via llamadas API (Referencias, comentarios WFW:commentAPI). Si lo defines como "moderado", todos los comentarios de este tipo siempre necesitarn ser aprobados primero. Si seleccionas "rechazar", sern completamente prohibidos. Si seleccionas "ninguno", los comentarios sern tratados como comentarios comunes..');
@define('PLUGIN_EVENT_SPAMBLOCK_API_MODERATE', 'moderado');
@define('PLUGIN_EVENT_SPAMBLOCK_API_REJECT', 'rechazar');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_API', 'No s permiten comentarios creados por APIs (i.e. referencias)');

@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_ACTIVATE', 'Activar wordfilter');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_ACTIVATE_DESC', 'Busca comentarios con ciertas palabras y los marca como spam.');

@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS', 'Wordfilter para URLs');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS_DESC', 'Se permiten expresiones regulares, separa las palabras con punto y coma(;).');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS', 'Wordfilter para nombres de autor');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS_DESC', 'Se permiten expresiones regulares, separa las palabras con punto y coma(;).');

?>

==> serendipity-1.3.1.tbz: www/serendipity/plugins/serendipity_event_spamblock/lang_es.inc.php <==
<?php # $Id: lang_es.inc.php 1561 2007-01-02 10:15:53Z garvinhicking $
/**
 *  @version $Revision: 1561 $
 *  @author Rodrigo Lazo Paz <rlazo.paz@gmail.com>
 *  EN-Revision: 690
 */

@define('PLUGIN_EVENT_SPAMBLOCK_TITLE', 'Proteccin anti-Spam');
@define('PLUGIN_EVENT_SPAMBLOCK_DESC', 'Una variedad de mtodos para prevenir el spam en los comentarios');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_BODY', 'Proteccin anti-Spam: Mensaje invlido.');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_IP', 'Proteccin anti-Spam: No puedes colocar un nuevo comentario tan pronto luego de haber ya hecho uno.');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_KILLSWITCH', 'Este blog est en "Modo de Emergencia de Bloqueo de comentarios", por favor regresa ms tarde');
@define('PLUGIN_EVENT_SPAMBLOCK_BODYCLONE', 'No permitir comentarios duplicados');
@define('PLUGIN_EVENT_SPAMBLOCK_BODYCLONE_DESC', 'Evita que los usuarios envien un comentario que contiene el mismo cuerpo que un comentario distinto ya enviado');
@define('PLUGIN_EVENT_SPAMBLOCK_KILLSWITCH', 'Desactivacin de emergencia de comentarios');
@define('PLUGIN_EVENT_SPAMBLOCK_KILLSWITCH_DESC', 'Inhabilita temporalmente los comentarios de todas las entradas. til si tu blog est siendo atacado por spam.');
@define('PLUGIN_EVENT_SPAMBLOCK_IPFLOOD', 'Intervaluo de bloqueo IP');
@define('PLUGIN_EVENT_SPAMBLOCK_IPFLOOD_DESC', 'Permite enviar comentarios a un IP cada n minutos. til para prevenir sobrecarga de comentarios.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS', 'Activar Captchas');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_DESC', 'Forzar a los usuarios a introducir una cadena al azar mostrada en una imagen especialmente diseada. Esta opcin imposibilitar envos automticos a tu blog. Por favor ten en cuenta que personas con problemas visuales podran encontrar dificil leer los captchas.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC', 'Para prevenir un ataque spam en los comentarios por parte de bots, por favor ingresa la cadena que ves en la imagen mostrada ms abajo en la apropiada caja de texto. Tu comentario ser aceptado slo si ambas cadenas son iguales. Por favor, asegrate que tu navegador soporta y acepta cookies, o tu comentario no podr ser verificado correctamente.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC2', 'Ingresa la cadena que ves ms abajo en la caja de texto!');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_USERDESC3', 'Ingresa la cadena de proteccin contra spam de la imgen mostrada abajo: ');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_CAPTCHAS', 'No has ingresado correctamente la cadena de proteccin contra spam mostrada en la imagen. Por favor, mrala e ingresa su valor en la caja de texto.');
@define('PLUGIN_EVENT_SPAMBLOCK_ERROR_NOTTF', 'Captchas deshabilitados en tu servidor. Necesitas GDLib y las libreras freetype compiladas con PHP, adems que de los archivos .TTF residan en tu directorio.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_TTL', 'Forzar captchas luego de cuantos das');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHAS_TTL_DESC', 'Los captchas pueden ser reforzados dependiendo de la edad de tu artculo. Ingresa la cantidad de das luego de los cuales ser necesario ingresar el captcha. Si lo defines en 0, siempre sern utilizados.');
@define('PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATION', 'Forzar la moderacin en los comentarios luego de cuntos das');
@define('PLUGIN_EVENT_SPAMBLOCK_FORCEMODERATION_DESC', 'Puedes configurar todos los comentarios a las entradas como automticamente moderados. Ingresa la edad de la entrada en das, luego de la cual ser auto-moderada. 0 significa no auto-moderacin.');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_MODERATE', 'Cuntos enlaces antes de que se modere un comentario');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_MODERATE_DESC', 'Cuando un comentario alcanza una cierta cantidad de enlaces, se puede configurar para que sea moderado. 0 significa que no se realizar esta comprobacin de enlaces.');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_REJECT', 'Cuntos enlaces antes de que se rechace un comentario');
@define('PLUGIN_EVENT_SPAMBLOCK_LINKS_REJECT_DESC', 'Cuando un comentario alcance un cierto nmero de enlaces, ese comentario puede ser rechazado. 0 significa que no se realizar esta comprobacin de enlaces.');
@define('PLUGIN_EVENT_SPAMBLOCK_NOTICE_MODERATION', 'Debido a ciertas condiciones, tu comentario ha sido marcado de manera que requiere moderacin por parte del dueo de este blog.');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHA_COLOR', 'Color de fondo del captcha');
@define('PLUGIN_EVENT_SPAMBLOCK_CAPTCHA_COLOR_DESC', 'Ingresa valores RGB: 0,255,255');

@define('PLUGIN_EVENT_SPAMBLOCK_LOGFILE', 'Ubicacin de la bitcora(logfile)');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGFILE_DESC', 'Informacin sobre comentarios rechazados/moderados puede ser puede ser escrita en una bitcora. Si lo dejas en blanco no se har reporte alguno.');

@define('PLUGIN_EVENT_SPAMBLOCK_REASON_KILLSWITCH', 'Bloqueo de comentarios de emergencia');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_BODYCLONE', 'Comentario duplicado');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_IPFLOOD', 'Bloqueo IP');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_CAPTCHAS', 'Captcha invlido (Ingresado: %s, Esperado: %s)');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_FORCEMODERATION', 'Moderacin automtica luego de X das');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_LINKS_REJECT', 'Demasiados hiper-enlaces');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_LINKS_MODERATE', 'Demasiados hiper-enlaces');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL', 'Ocultar direcciones e-mail de los usuarios que comentan');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL_DESC', 'No mostrar direccin e-mail alguna de los usuarios que comenten');
@define('PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL_NOTICE', 'Direcciones e-mail no sern mostradas y slo sern utilizadas para notificaciones a travs de esa va');

@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE', 'Elige el mtodo de reporte');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_DESC', 'Reportes sobre comentarios rechazados pueden ser hechos a travs de la base de datos o en un archivo de texto plano');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_FILE', 'Archivo (la opcin "logfile" debajo)');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_DB', 'Base de datos');
@define('PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_NONE', 'Sin reporte');

@define('PLUGIN_EVENT_SPAMBLOCK_API_COMMENTS', 'Como manejar los comentarios hechos via APIs');
@define('PLUGIN_EVENT_SPAMBLOCK_API_COMMENTS_DESC', 'Esta opcin afecta la moderacin sobre los comentarios hechos via llamadas API (Referencias, comentarios WFW:commentAPI). Si lo defines como "moderado", todos los comentarios de este tipo siempre necesitarn ser aprobados primero. Si seleccionas "rechazar", sern completamente prohibidos. Si seleccionas "ninguno", los comentarios sern tratados como comentarios comunes..');
@define('PLUGIN_EVENT_SPAMBLOCK_API_MODERATE', 'moderado');
@define('PLUGIN_EVENT_SPAMBLOCK_API_REJECT', 'rechazar');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_API', 'No se permiten comentarios creados por APIs (i.e. referencias)');

@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_ACTIVATE', 'Activar filtro por palabras');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_ACTIVATE_DESC', 'Busca comentarios con ciertas palabras y los marca como spam.');

@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS', 'Filtro por palabras para URLs');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS_DESC', 'Se permiten expresiones regulares, separa las palabras con punto y coma(;).  Escribe las arrobas (@) por \\@.');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS', 'Filtro por palabras para nombres de autor');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_AUTHORS_DESC', PLUGIN_EVENT_SPAMBLOCK_FILTER_URLS_DESC);

@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_WORDS', 'Filtrado por palabras para el cuerpo del comentario');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_EMAILS', 'Filtrado por palabras para el correo electrnico');

@define('PLUGIN_EVENT_SPAMBLOCK_REASON_CHECKMAIL', 'Direccin e-mail invlida');
@define('PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL', 'Revisar direccin e-mail?');
@define('PLUGIN_EVENT_SPAMBLOCK_REQUIRED_FIELDS', 'Campos del comentario requeridos');
@define('PLUGIN_EVENT_SPAMBLOCK_REQUIRED_FIELDS_DESC', 'Ingresa una lista de los campos requeridos que necesitan ser llenados cuando un usuario hace un comentario. Separa mltiples campos con una ",". Las palabras claves disponibles son: nombre(name), email, url, replyTo, comentario(comment)');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_REQUIRED_FIELD', 'No has especificado el campo %s!');

@define('PLUGIN_EVENT_SPAMBLOCK_CONFIG', 'Configura los mtodos Anti-Spam');
@define('PLUGIN_EVENT_SPAMBLOCK_ADD_AUTHOR', 'Bloquear este autor a travs de la extensin Spamblock');
@define('PLUGIN_EVENT_SPAMBLOCK_ADD_URL', 'Bloquear esta URL a travs de la extensin Spamblock');
@define('PLUGIN_EVENT_SPAMBLOCK_ADD_EMAIL', 'Bloquear este correo electrnico a travs de la extensin Spamblock');
@define('PLUGIN_EVENT_SPAMBLOCK_REMOVE_AUTHOR', 'Desbloquear este autor a travs de la extensin Spamblock');
@define('PLUGIN_EVENT_SPAMBLOCK_REMOVE_URL', 'Desbloquear estea URL a travs de la extensin Spamblock');
@define('PLUGIN_EVENT_SPAMBLOCK_REMOVE_EMAIL', 'Desbloquear este correo electrnico a travs de la extensin Spamblock');

@define('PLUGIN_EVENT_SPAMBLOCK_BLOGG_SPAMLIST', 'Activar el filtrado de URL atravs de la lista negra blogg.de');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_BLOGG_SPAMLIST', 'Filtrado a travs de la lista negra blogg.de');

@define('PLUGIN_EVENT_SPAMBLOCK_REASON_TITLE', 'Titulo de la entrada igual al comentario');
@define('PLUGIN_EVENT_SPAMBLOCK_FILTER_TITLE', 'Rechaza comentarios que slo contengan ttulo');
@define('PLUGIN_EVENT_SPAMBLOCK_TRACKBACKURL', 'Revisar Trackback URLs');
@define('PLUGIN_EVENT_SPAMBLOCK_TRACKBACKURL_DESC', 'Slo permitir trackbacks, cuando el URL contiene un enlace a tu blog');
@define('PLUGIN_EVENT_SPAMBLOCK_REASON_TRACKBACKURL', 'Trackback URL invlida.');
?>
